==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits:");
define("_BROWSERS","Browsers");
define("_OPERATINGSYS","Besturingssysteem");
define("_UNKNOWN","Onbekend");
define("_OTHER","Ander/Onbekend");
define("_MISCSTATS","Algemene statistieken");
define("_REGUSERS","Leden:");
define("_ACTIVEAUTHORS","Actieve auteurs:");
define("_STORIESPUBLISHED","Verhalen gepubliceerd:");
define("_SACTIVETOPICS","Actieve onderwerpen:");
define("_COMMENTSPOSTED","Opmerkingen geplaatst:");
define("_SSPECIALSECT","Speciale secties:");
define("_ARTICLESSEC","Artikelen in secties:");
define("_LINKSINLINKS","Links in weblinks:");
define("_LINKSCAT","Categorien in links:");
define("_NEWSWAITING","Nieuws wachtend op publicatie:");
define("_NUKEVERSION","PHP-Nuke versie:");
define("_SEARCHENGINES","Zoekmachines:");
define("_BOTS","Robots/Spiders");
define("_STATS","Toegangsstatistieken");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits:");
define("_BROWSERS","Browsers");
define("_OPERATINGSYS","Besturingssysteem");
define("_UNKNOWN","Onbekend");
define("_OTHER","Ander/Onbekend");
define("_MISCSTATS","Algemene statistieken");
define("_REGUSERS","Leden:");
define("_ACTIVEAUTHORS","Actieve auteurs:");
define("_STORIESPUBLISHED","Verhalen gepubliceerd:");
define("_SACTIVETOPICS","Actieve onderwerpen:");
define("_COMMENTSPOSTED","Opmerkingen geplaatst:");
define("_SSPECIALSECT","Speciale secties:");
define("_ARTICLESSEC","Artikelen in secties:");
define("_LINKSINLINKS","Links in weblinks:");
define("_LINKSCAT","Categorien in links:");
define("_NEWSWAITING","Nieuws wachtend op publicatie:");
define("_NUKEVERSION","PHP-Nuke versie:");
define("_SEARCHENGINES","Zoekmachines:");
define("_BOTS","Robots/Spiders");
define("_STATS","Toegangsstatistieken");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
